@@ -169,18 +169,6 @@ ArtIRect             eel_gdk_pixbuf_intersect                 (const GdkPixbuf
 							       int                    pixbuf_y,
 							       ArtIRect               rectangle);
 
-/* Text drawing. */
-void                 eel_gdk_pixbuf_draw_layout               (GdkPixbuf             *pixbuf,
-							       int                    x,
-							       int                    y,
-							       guint32                color,
-							       PangoLayout           *layout);
-
-void                 eel_gdk_pixbuf_draw_layout_clipped       (GdkPixbuf             *pixbuf,
-							       ArtIRect               region,
-							       guint32                color,
-							       PangoLayout           *layout);
-
 /* Scales large pixbufs down fast */
 GdkPixbuf *          eel_gdk_pixbuf_scale_down                (GdkPixbuf *pixbuf,
 							       int dest_width,
